@@ -3,11 +3,11 @@
 {
   if (startsWith(timespan_unit, "month"))
   {
-    30.5
+    30.436875
   }
   else if (startsWith(timespan_unit, "year"))
   {
-    365
+    365.2425
   }
   else if (startsWith(timespan_unit, "day"))
   {
@@ -186,6 +186,46 @@
     mutate(label=rownames(result$diff_pairwise$p.value))
 }
 
+
+.survival_rate <- function(result,
+                           times,
+                           percentage_decimal_places,
+                           time_precision,
+                           timespan_unit)
+{
+  timespan_scaling <- .timespan_scaling(timespan_unit)
+
+  # The "extend" argument mitigates the risk of error when asking for time points without subjects
+  summary_data <- summary(result$fit, times, extend=TRUE)
+
+  summary_data[c("time", "n.risk", "n.event", "surv", "lower", "upper")] %>%
+    as_tibble() %>%
+    select(time,
+           n_at_risk = n.risk,
+           n_events = n.event,
+           rate = surv,
+           Lower.CI = lower,
+           Upper.CI = upper) %>%
+    mutate(
+      time = time / timespan_scaling,
+      time_label = as_formatted_number(time, time_precision),
+      across(rate:Upper.CI, .names = "{.col} percentage",
+             ~as_percentage_label(.x, percentage_decimal_places))
+      ) ->
+    rates
+
+  if (.has_strata(result))
+  {
+    rates %<>%
+      mutate(
+        stratum = result$by,
+        stratum_value = result$factorLabels[summary_data$strata]) %>%
+      relocate(stratum, stratum_value)
+  }
+  rates
+}
+
+
 #' Extract results from univariate survival analysis structured as data frames
 #'
 #' @param format_numbers If true, all numbers will be formatted for printing according to the following options
@@ -220,15 +260,6 @@ survival_data_frames <- function(result,
   }
 
   timespan_unit <- match.arg(timespan_unit)
-  timespanScaling <- 1
-  if (startsWith(timespan_unit, "month"))
-  {
-    timespanScaling <- 30.5
-  }
-  else if (startsWith(timespan_unit, "year"))
-  {
-    timespanScaling <- 365
-  }
 
   l <- list(
     "cohortMetadata" = .overall_metadata(result,
@@ -275,11 +306,11 @@ survival_data_frames <- function(result,
 #'               as returned by \code{\link{analyse_survival}}
 #' @param term   The item to be retrieved:
 #'    \itemize{
-#'      \item \code{"survfit"} containing the result of the \code{\link{survfit}} function
-#'      \item \code{"survdiff"} containing the result of the \code{\link{survdiff}} function
-#'      \item \code{"survfit_overall"} containing the result of the \code{\link{survfit}}
+#'      \item \code{"survfit"} containing the result of the \code{\link[survival]{survfit}} function
+#'      \item \code{"survdiff"} containing the result of the \code{\link[survival]{survdiff}} function
+#'      \item \code{"survfit_overall"} containing the result of the \code{\link[survival]{survfit}}
 #'            function without terms, i.e. the full group not comparing subgroups
-#'      \item \code{"coxph"} containing the result of the \code{\link{coxph}} function
+#'      \item \code{"coxph"} containing the result of the \code{\link[survival]{coxph}} function
 #'      \item \code{"p"} The log-rank p value (if \code{by} provided at least two strata)
 #'    }
 #' @return object as specified by \code{term}, or NULL if not contained in \code{result}
@@ -312,7 +343,7 @@ pluck_survival_analysis  <- function(result, term)
   {
     result[["coxph"]]
   }
-  if (term == "survdiff")
+  else if (term == "survdiff")
   {
     result[["diff"]]
   }
@@ -355,15 +386,6 @@ format.SurvivalAnalysisUnivariateResult <- function(x,
   }
 
   timespan_unit <- match.arg(timespan_unit)
-  timespanScaling <- 1
-  if (startsWith(timespan_unit, "month"))
-  {
-    timespanScaling <- 30.5
-  }
-  else if (startsWith(timespan_unit, "year"))
-  {
-    timespanScaling <- 365
-  }
 
   dfs <- list()
   dfs[["Overall Analysis:"]] <-
@@ -522,6 +544,7 @@ write_survival <- function(...,
        include_end_separator = include_end_separator,
        timespan_unit = timespan_unit
   ) %>%
+    flatten_chr() %>%
     str_c(collapse = "") %>%
     cat(file = file)
 }
@@ -566,3 +589,102 @@ survival_essentials <- function(result,
   invisible(str)
 }
 
+#' Compute survival rates by KM estimate for given time points for an
+#' univariate survival analysis
+#'
+#' @param result The result generated by \code{\link{analyse_survival}}
+#' @param time_points Time points to compute survival rate at
+#' @param percentage_decimal_places,time_precision Precision with which to print floating point values in their label form
+#' @param timespan_unit Unit for time spans: "days", "months" or "years".
+#'
+#' @return A data frame with time, number at risk, number with event,
+#' survival rate with CI, and time and rate formatted for printing
+#' @export
+survival_rates <- function(result,
+                           time_points,
+                           percentage_decimal_places = 1,
+                           time_precision = 0,
+                           timespan_unit = c("days", "months", "years"))
+{
+  if (is.null(result))
+  {
+    warning("survival_rates called with NULL object. Returning empty tibble.")
+    return(tibble())
+  }
+  if (!inherits(result, "SurvivalAnalysisUnivariateResult"))
+  {
+    stop("survival_rates called with inappropriate object, type ",
+         type_of(result), " class ", class(result))
+  }
+
+  timespan_unit <- match.arg(timespan_unit)
+
+  .survival_rate(result,
+                 time_points,
+                 percentage_decimal_places,
+                 time_precision,
+                 timespan_unit)
+}
+
+#' Write survival rates for one or multiple survival
+#' analysis results in a CSV file.
+#'
+#' As write_survival takes potentially multiple objects, it cannot
+#' return its input in a cleanly defined way.
+#' You can still elegantly combine \code{write_survival} in a pipe followed by
+#' \code{\link{kaplan_meier_plot}} or \code{\link{kaplan_meier_grid}}
+#' for a single input object if you apply the
+#' tee pipe operator \code{\%T>\%} in front of \code{write_survival}.
+#'
+#' @param ... Results generated by \code{\link{analyse_survival}},
+#' or lists of such objects
+#' @param file A connection, or a character string naming the file to print to.
+#' (see \code{\link{cat}})
+#' @param time_points Time points to compute survival rate at
+#' @param label A label describing the result,
+#'    or a vector of the same size as results in ... (will then be mapped 1:1).
+#'    Recommended to distinguish result lines from multiple results in ...
+#' @param writer A writer function such as write.csv
+#' @param writer_args Parameters to pass to the writer function
+#' @param percentage_decimal_places,time_precision Precision with which to print floating point values in their label form
+#' @param timespan_unit Unit for time spans: "days", "months" or "years"
+#'
+#' @return None (invisible NULL).
+#'
+#' @export
+write_survival_rates <- function(...,
+                                 file,
+                                 time_points,
+                                 label = NULL,
+                                 writer = write.csv,
+                                 writer_args = list(),
+                                 percentage_decimal_places = 1,
+                                 time_precision = 0,
+                                 timespan_unit = c("days", "months", "years"))
+{
+  # take dots and splice bare lists
+  results <- flatten_if(list2(...), is_bare_list)
+  timespan_unit <- match.arg(timespan_unit)
+
+  if (is.null(label))
+  {
+    label <- list(NULL) # need to wrap for pmap
+  }
+
+  rates_with_labels <- function(result, .label)
+  {
+    result %>%
+      survival_rates(time_points = time_points,
+                     percentage_decimal_places = percentage_decimal_places,
+                     time_precision = time_precision,
+                     timespan_unit = timespan_unit) %>%
+      mutate(label=.label, .before=1)
+  }
+
+  pmap(list(results,
+            label),
+       rates_with_labels
+  ) %>%
+    list_rbind() %>%
+    {inject(writer(., file=file, !!!writer_args))}
+}
