@@ -4,10 +4,10 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-## ---- echo=FALSE, results='asis'----------------------------------------------
+## ----echo=FALSE, results='asis'-----------------------------------------------
 knitr::kable(head(survival::lung, 10))
 
-## ---- warning=FALSE, message=FALSE--------------------------------------------
+## ----warning=FALSE, message=FALSE---------------------------------------------
 library(tidyverse)
 library(tidytidbits)
 library(survivalAnalysis)
@@ -43,10 +43,10 @@ survival::lung %>%
 ## -----------------------------------------------------------------------------
 exp((75-45)*log(1.04)) 
 
-## ---- fig.width=8, fig.height=5-----------------------------------------------
+## ----fig.width=8, fig.height=5------------------------------------------------
 forest_plot(result)
 
-## ---- fig.width=9.7, fig.height=1.7-------------------------------------------
+## ----fig.width=9.7, fig.height=1.7--------------------------------------------
 forest_plot(result,
             factor_labeller = covariate_names,
             endpoint_labeller = c(time="OS"),
@@ -56,7 +56,7 @@ forest_plot(result,
             relative_widths = c(1, 1.5, 1),
             HR_x_breaks = c(0.25, 0.5, 0.75, 1, 1.5, 2))
 
-## ---- fig.width=9.7, fig.height=1.7-------------------------------------------
+## ----fig.width=9.7, fig.height=1.7--------------------------------------------
 
 df <- survival::lung %>% mutate(sex=rename_factor(sex, `1` = "male", `2` = "female"))
 
@@ -73,12 +73,12 @@ map(vars(age, sex, ph.ecog, wt.loss), function(by)
               labels_displayed = c("endpoint", "factor", "n"),
               ggtheme = ggplot2::theme_bw(base_size = 10))
 
-## ---- fig.width=9.7, fig.height=1.7-------------------------------------------
+## ----fig.width=9.7, fig.height=1.7--------------------------------------------
 
 survival::lung %>% 
   mutate(kras=sample(c("WT", "G12C", "G12V", "G12D", "G12A"), 
                      nrow(.), 
-                     replace = T, 
+                     replace = TRUE, 
                      prob = c(0.6, 0.24, 0.16, 0.06, 0.04))
           ) %>%
   analyse_survival(vars(time, status), by=kras) %>%
